@@ -70,7 +70,7 @@ def pbdesign(n):
             ))))
     
     # Kronecker product construction
-    for i in xrange(e):
+    for i in range(e):
         H = np.vstack((np.hstack((H, H)), np.hstack((H, -H))))
     
     # Reduce the size of the matrix as needed
@@ -78,4 +78,4 @@ def pbdesign(n):
     
     return np.flipud(H)
     
-    
\ No newline at end of file
+    
